==> haskell-typst-0.5.0.1-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-typst.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 typst
version:              0.5.0.1
visibility:           public
id:                   typst-0.5.0.1-FuDMNbcO6MDAbs30AMJMdl
key:                  typst-0.5.0.1-FuDMNbcO6MDAbs30AMJMdl
license:              BSD-3-Clause
copyright:            Copyright 2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Parsing and evaluating typst syntax.
description:
    A library for parsing and evaluating typst syntax.
    Typst (<https://typst.app>) is a document layout and
    formatting language. This library targets typst 0.10
    and currently offers only partial support.

category:             Text
abi:                  c6e5fcf1597a8a8e651f486f4a0b49a3
exposed:              True
exposed-modules:
    Typst Typst.Evaluate Typst.Methods Typst.Parse Typst.Syntax
    Typst.Types Typst.Util

hidden-modules:
    Typst.Bind Typst.Regex Typst.Show Typst.Module.Standard
    Typst.Module.Math Typst.Module.Calc Typst.MathClass

import-dirs:          /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typst
hs-libraries:         HStypst-0.5.0.1-FuDMNbcO6MDAbs30AMJMdl
depends:
    aeson-2.1.2.1-Kzzie09M6AYFH8VDx0mx86 array-0.5.4.0 base-4.17.2.1
    bytestring-0.11.5.3 cassava-0.5.3.2-DFrCUVuqbOkG6iHhe49yMt
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    ordered-containers-0.2.4-9Z1IPGPP0nR64UcxttwlAD parsec-3.1.16.1
    pretty-1.1.3.6 regex-tdfa-1.3.2.2-Lx2wVcETmehVQz7NWfugc
    scientific-0.3.7.0-Jh9tJE2sLMpFL2bSsP8DMA text-2.0.2 time-1.12.2
    toml-parser-1.3.2.0-BrsQUajjItp8RdSDHcItmW
    typst-symbols-0.1.5-CKv9nghfbzV9YElGsqLgYY
    vector-0.13.1.0-DP5vqiFKsIZ25TyoutQAjD
    xml-conduit-1.9.1.4-8jb0ZVhv2LCKph8wCHjXC8
    yaml-0.11.11.2-FQGR7qmzYmVGeoVQVKTN0

haddock-interfaces:   /usr/share/doc/haskell-typst/html/typst.haddock
haddock-html:         /usr/share/doc/haskell-typst/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-typst-0.5.0.1-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-typst.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 typst
version:              0.5.0.1
visibility:           public
id:                   typst-0.5.0.1-1xF1y98kta4ITForcTZPj3
key:                  typst-0.5.0.1-1xF1y98kta4ITForcTZPj3
license:              BSD-3-Clause
copyright:            Copyright 2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Parsing and evaluating typst syntax.
description:
    A library for parsing and evaluating typst syntax.
    Typst (<https://typst.app>) is a document layout and
    formatting language. This library targets typst 0.10
    and currently offers only partial support.

category:             Text
abi:                  c457d28930cce49f09c96b297dcffad0
exposed:              True
exposed-modules:
    Typst Typst.Evaluate Typst.Methods Typst.Parse Typst.Syntax
    Typst.Types Typst.Util

hidden-modules:
    Typst.Bind Typst.Regex Typst.Show Typst.Module.Standard
    Typst.Module.Math Typst.Module.Calc Typst.MathClass

import-dirs:          /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typst
hs-libraries:         HStypst-0.5.0.1-1xF1y98kta4ITForcTZPj3
depends:
    aeson-2.1.2.1-3xjz2RyG2JVHhJgBzFxi7A array-0.5.4.0 base-4.17.2.1
    bytestring-0.11.5.3 cassava-0.5.3.2-4if38KQLdfpKUZhCbBCJdB
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    ordered-containers-0.2.4-7Rdge8IHH5rBc7J8s0KCoz parsec-3.1.16.1
    pretty-1.1.3.6 regex-tdfa-1.3.2.2-LivcOdtZX8FLXw70uGvuNe
    scientific-0.3.7.0-LKd2L2qVPICBdMYOyCcex4 text-2.0.2 time-1.12.2
    toml-parser-1.3.2.0-9n38JdSj657AVk1CAevMIB
    typst-symbols-0.1.5-CKv9nghfbzV9YElGsqLgYY
    vector-0.13.1.0-93FGbMU4lvK4yKJkYGTpJX
    xml-conduit-1.9.1.4-5vcQxiFJHc9Jpl6c1AzhY1
    yaml-0.11.11.2-JVC7JzNxnvLG8NF94fNnFV

haddock-interfaces:   /usr/share/doc/haskell-typst/html/typst.haddock
haddock-html:         /usr/share/doc/haskell-typst/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
